@@ -23,11 +23,13 @@
 typedef struct
 {
 	gchar *logfile;
-	int width, height;
+	GSList *logs;
+	int width, height, fontsize;
 } UserPrefsStruct;
 
 void prefs_save (GConfClient *client, UserPrefsStruct *prefs);
 UserPrefsStruct *prefs_load (GConfClient *client);
+void prefs_free_loglist (UserPrefsStruct *prefs);
 void prefs_store_size (GtkWidget *window, UserPrefsStruct *prefs);
 
 #endif /* __LOG_PREFS_H__ */
